#####################
Data table histograms
#####################

One can easily generate a histogram of a tabular data using the :meth`hist` instance method.
For example, as defined for the `SnglBurstTable`:

.. automethod:: SnglBurstTable.hist

Following the worked example on :doc:`plotting an event table histogram <../examples/table/histogram>` we can study the cumulative distribution of event signal-to-noise ratio:

.. plot:: ../examples/table/histogram.py

|
